import {createClient as createLibSQLClient} from "@libsql/client";
import "websocket-polyfill";
import {PrismaClient} from "@prisma/client";
import {PrismaLibSQL} from "@prisma/adapter-libsql";
import {NostrSmtpServer} from "./smtpServer";
import {HttpServer} from "./httpServer";

if (!process.env.BASE_DOMAIN)
  throw new Error("BASE_DOMAIN is not set");
if (!process.env.DB_URL)
  throw new Error("DB_URL is not set");
if (!process.env.PUBLIC_API_BASE_URL)
  throw new Error("PUBLIC_API_BASE_URL is not set");
if (!process.env.MASTER_NSEC)
  throw new Error("MASTER_NSEC is not set");

const dbClient = createLibSQLClient({
  url: process.env.DB_URL,
});

const db = new PrismaClient({
  adapter: new PrismaLibSQL(dbClient)
});

new NostrSmtpServer(db, parseInt(process.env.SMTP_PORT || '6587'));
new HttpServer(db, parseInt(process.env.HTTP_PORT || '3000'));